@@ -41,7 +41,7 @@ Session::Session(QObject *parent)
     connect(m_thread, &SessionThread::authenticationDone, this, &Session::authenticationDone);
     connect(m_thread, &SessionThread::sslError, this, &Session::sslError);
     connect(m_thread, &SessionThread::sslDone, this, &Session::sslDone);
-    connect(m_thread, &SessionThread::socketDisconnected, [this]() {
+    connect(m_thread, &SessionThread::socketDisconnected, this, [this]() {
         m_connected = false;
         m_disconnected = true;
     });
@@ -261,7 +261,8 @@ KManageSieve::AuthDetails Session::requestAuthDetails(const QUrl &url)
         url.host());
 
     QPointer<KPasswordDialog> dlg = new KPasswordDialog(nullptr, KPasswordDialog::ShowUsernameLine | KPasswordDialog::ShowKeepPassword);
-    dlg->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
+    dlg->setRevealPasswordMode(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")) ? KPassword::RevealMode::OnlyNew
+                                                                                                  : KPassword::RevealMode::Never);
     dlg->setUsername(ai.username);
     dlg->setPassword(ai.password);
     dlg->setKeepPassword(ai.keepPassword);
