@@ -19,8 +19,8 @@ using namespace KSieveUi;
 SieveActionKeep::SieveActionKeep(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
     : SieveAction(sieveGraphicalModeWidget, QStringLiteral("keep"), i18n("Keep"), parent)
 {
-    mHasImapFlag4Support = sieveCapabilities().contains(QLatin1String("imap4flags"));
-    mHasFlagSupport = sieveCapabilities().contains(QLatin1String("imapflags")) || mHasImapFlag4Support;
+    mHasImapFlag4Support = sieveCapabilities().contains(QLatin1StringView("imap4flags"));
+    mHasFlagSupport = sieveCapabilities().contains(QLatin1StringView("imapflags")) || mHasImapFlag4Support;
 }
 
 QString SieveActionKeep::code(QWidget *w) const
