@@ -17,7 +17,7 @@
 #include <QHideEvent>
 #include <QPushButton>
 
-#include <kmanagesieve/sievejob.h>
+#include "kmanagesieve/sievejob.h"
 
 #include <QTreeWidget>
 #include <QVBoxLayout>
@@ -103,7 +103,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(KSieveCore::SieveImapPassword
     connect(close, &QPushButton::clicked, this, &ManageSieveScriptsDialog::accept);
     buttonLayout->addWidget(close);
 
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myManageSieveScriptsDialog));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myManageSieveScriptsDialog));
     const QSize size = group.readEntry("Size", QSize());
     if (size.isValid()) {
         resize(size);
@@ -115,7 +115,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(KSieveCore::SieveImapPassword
 ManageSieveScriptsDialog::~ManageSieveScriptsDialog()
 {
     disconnect(d->mTreeView, &CustomManageSieveWidget::updateButtons, this, &ManageSieveScriptsDialog::slotUpdateButtons);
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myManageSieveScriptsDialog));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myManageSieveScriptsDialog));
     group.writeEntry("Size", size());
     // prevent QTreeWidget signals triggered by it's destructor from calling our slots
     d->mTreeView->disconnect(this);
